@@ -731,6 +731,8 @@ get_tokens_and_identity (GoaOAuthProvider *provider,
 
       scrolled_window = gtk_scrolled_window_new (NULL, NULL);
       gtk_widget_set_size_request (scrolled_window, 500, 400);
+      gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
+                                           GTK_SHADOW_IN);
       gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
                                       GTK_POLICY_AUTOMATIC,
                                       GTK_POLICY_AUTOMATIC);
